aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThomas White <taw@physics.org>2009-11-27 15:19:13 +0100
committerThomas White <taw@physics.org>2009-11-27 15:19:13 +0100
commit7c521735bc08fefe9d59f6f583acb8e3144ede59 (patch)
treeb7124444d1bcd1125f5a21c2aedc704317e3b106
parent3a6f08ad10aa901d3c75165c3c2e47361c719847 (diff)
10cm camera length
5cm needs too many reflections...
-rw-r--r--src/pattern_sim.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/pattern_sim.c b/src/pattern_sim.c
index e9c56fb3..ea487c97 100644
--- a/src/pattern_sim.c
+++ b/src/pattern_sim.c
@@ -148,7 +148,7 @@ int main(int argc, char *argv[])
image.fmode = FORMULATION_CLEN;
image.x_centre = 512.5;
image.y_centre = 512.5;
- image.camera_len = 0.05; /* 5 cm (front CCD can move from 5cm-20cm) */
+ image.camera_len = 0.10; /* 10 cm (front CCD can move from 5cm-20cm) */
image.resolution = 13333.3; /* 75 micron pixel size */
image.xray_energy = eV_to_J(2.0e3); /* 2 keV energy */
image.lambda = ph_en_to_lambda(image.xray_energy); /* Wavelength */